@@ -120,7 +120,7 @@ class WeatherBitApiClient:
                 clouds=base_data["clouds"],
                 solar_rad=base_data["solar_rad"],
                 wind_spd=self.cnv.windspeed(base_data["wind_spd"]),
-                wind_spd_kmh=self.cnv.windspeed(base_data["wind_spd"], True),
+                wind_spd_kmh=self.cnv.windspeed_kmh(base_data["wind_spd"]),
                 wind_spd_knots=self.cnv.windspeed_knots(base_data["wind_spd"]),
                 wind_cdir=self.calc.wind_direction(base_data["wind_dir"]),
                 wind_dir=base_data["wind_dir"],
@@ -192,27 +192,27 @@ class WeatherBitApiClient:
                 key=self.station_data.key,
                 utc_time=self.cnv.utc_from_timestamp(base_data["ts"]),
                 city_name=data["city_name"],
-                temp=self.cnv.temperature(base_data["temp"]),
-                max_temp=self.cnv.temperature(base_data["max_temp"]),
-                min_temp=self.cnv.temperature(base_data["min_temp"]),
-                app_max_temp=self.cnv.temperature(base_data["app_max_temp"]),
-                app_min_temp=self.cnv.temperature(base_data["app_min_temp"]),
+                temp=base_data["temp"],
+                max_temp=base_data["max_temp"],
+                min_temp=base_data["min_temp"],
+                app_max_temp=base_data["app_max_temp"],
+                app_min_temp=base_data["app_min_temp"],
                 humidity=base_data["rh"],
-                pres=self.cnv.pressure(base_data["pres"]),
-                slp=self.cnv.pressure(base_data["slp"]),
+                pres=base_data["pres"],
+                slp=base_data["slp"],
                 clouds=base_data["clouds"],
-                wind_spd=self.cnv.windspeed(base_data["wind_spd"]),
-                wind_gust_spd=self.cnv.windspeed(base_data["wind_gust_spd"]),
+                wind_spd=base_data["wind_spd"],
+                wind_gust_spd=base_data["wind_gust_spd"],
                 wind_cdir=self.calc.wind_direction(base_data["wind_dir"]),
                 wind_dir=base_data["wind_dir"],
-                dewpt=self.cnv.temperature(base_data["dewpt"]),
+                dewpt=base_data["dewpt"],
                 pop=base_data["pop"],
                 weather_icon=base_data["weather"]["icon"],
                 condition=self.cnv.condition_from_code(base_data["weather"]["code"], self._is_night),
                 weather_text=base_data["weather"]["description"],
-                vis=self.cnv.distance(base_data["vis"]),
-                precip=self.cnv.rain(base_data["precip"]),
-                snow=self.cnv.rain(base_data["snow"]),
+                vis=base_data["vis"],
+                precip=base_data["precip"],
+                snow=base_data["snow"],
                 uv=base_data["uv"],
                 ozone=base_data["ozone"],
             )
@@ -222,27 +222,27 @@ class WeatherBitApiClient:
                 forecast_data = ForecastDetailDescription(
                     key=self.station_data.key,
                     utc_time=self.cnv.utc_from_timestamp(item["ts"]),
-                    temp=self.cnv.temperature(item["temp"]),
-                    max_temp=self.cnv.temperature(item["max_temp"]),
-                    min_temp=self.cnv.temperature(item["min_temp"]),
-                    app_max_temp=self.cnv.temperature(item["app_max_temp"]),
-                    app_min_temp=self.cnv.temperature(item["app_min_temp"]),
+                    temp=item["temp"],
+                    max_temp=item["max_temp"],
+                    min_temp=item["min_temp"],
+                    app_max_temp=item["app_max_temp"],
+                    app_min_temp=item["app_min_temp"],
                     humidity=item["rh"],
-                    pres=self.cnv.pressure(item["pres"]),
-                    slp=self.cnv.pressure(item["slp"]),
+                    pres=item["pres"],
+                    slp=item["slp"],
                     clouds=item["clouds"],
-                    wind_spd=self.cnv.windspeed(item["wind_spd"]),
-                    wind_gust_spd=self.cnv.windspeed(item["wind_gust_spd"]),
-                    wind_cdir=self.calc.wind_direction(item["wind_dir"]),
+                    wind_spd=item["wind_spd"],
+                    wind_gust_spd=item["wind_gust_spd"],
+                    wind_cdir=item["wind_dir"],
                     wind_dir=item["wind_dir"],
-                    dewpt=self.cnv.temperature(item["dewpt"]),
+                    dewpt=item["dewpt"],
                     pop=item["pop"],
                     weather_icon=item["weather"]["icon"],
                     condition=self.cnv.condition_from_code(item["weather"]["code"], False),
                     weather_text=item["weather"]["description"],
-                    vis=self.cnv.distance(item["vis"]),
-                    precip=self.cnv.rain(item["precip"]),
-                    snow=self.cnv.rain(item["snow"]),
+                    vis=item["vis"],
+                    precip=item["precip"],
+                    snow=item["snow"],
                     uv=item["uv"],
                     ozone=item["ozone"],
                 )
@@ -258,8 +258,8 @@ class WeatherBitApiClient:
         """Return unit of meassurement based on unit system."""
         density_unit = "kg/m^3" if self._is_metric else "lb/ft^3"
         distance_unit = "km" if self._is_metric else "mi"
-        length_unit = "m/s" if self._is_metric else "mi/h"
-        length_km_unit = "km/h" if self._is_metric else "mi/h"
+        length_unit = "m/s" if self._is_metric else "mph"
+        length_km_unit = "km/h" if self._is_metric else "mph"
         pressure_unit = "hPa" if self._is_metric else "inHg"
         precip_unit = "mm" if self._is_metric else "in"
 
@@ -281,7 +281,7 @@ class WeatherBitApiClient:
         method: str,
         endpoint: str,
     ) -> dict:
-        """Make a request against the SmartWeather API."""
+        """Make a request against the API."""
         use_running_session = self.req and not self.req.closed
 
         if use_running_session:
@@ -299,7 +299,7 @@ class WeatherBitApiClient:
         except client_exceptions.ClientError as err:
             if "403" in str(err):
                 raise InvalidApiKey("The API Key used is not valid. Try again with a new key.") from None
-            raise RequestError(f"Error requesting data from Meteobridge: {err}") from None
+            raise RequestError(f"Error requesting data from WeatherBit: {err}") from None
 
         finally:
             if not use_running_session:
